@@ -220,11 +220,11 @@ impl WidgetScheme {
 }
 
 pub trait FromColor {
-    fn from_tup(tup: (u8, u8, u8, u8)) -> Color;
+    fn from_rgba(tup: (u8, u8, u8, u8)) -> Color;
 }
 
 impl FromColor for Color {
-    fn from_tup(tup: (u8, u8, u8, u8)) -> Color {
-        Color::from_rgb(tup.0, tup.1, tup.2)
+    fn from_rgba(tup: (u8, u8, u8, u8)) -> Color {
+        Color::from_rgba_tuple(tup)
     }
 }
