@@ -4,8 +4,9 @@
 use crate::activated_color;
 use fltk::{app, draw::*, enums::Color};
 
-// taken from NTK's themes
+pub mod aqua;
 pub(crate) mod clean;
 pub(crate) mod crystal;
+pub mod fluent;
 pub(crate) mod gleam;
 pub(crate) mod svg_based;
